==> refcodes-filesystem-1.1.3-sources.jar: org/refcodes/filesystem/UnknownPathException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.filesystem.FileSystemException.FileSystemPathException;

public class UnknownPathException extends FileSystemPathException {

	private static final long serialVersionUID = 1L;

	public UnknownPathException( String aPath, String aMessage, String aErrorCode ) {
		super( aPath, aMessage, aErrorCode );
	}

	public UnknownPathException( String aPath, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aPath, aMessage, aCause, aErrorCode );
	}

	public UnknownPathException( String aPath, String message, Throwable cause ) {
		super( aPath, message, cause );
	}

	public UnknownPathException( String aPath, String message ) {
		super( aPath, message );
	}

	public UnknownPathException( String aPath, Throwable aCause, String aErrorCode ) {
		super( aPath, aCause, aErrorCode );
	}

	public UnknownPathException( String aPath, Throwable cause ) {
		super( aPath, cause );
	}
}

==> refcodes-filesystem-1.10.0-sources.jar: org/refcodes/filesystem/UnknownPathException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.filesystem.FileSystemException.FileSystemPathException;

/**
 * The Class UnknownPathException.
 */
public class UnknownPathException extends FileSystemPathException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public UnknownPathException( String aPath, String aMessage, String aErrorCode ) {
		super( aPath, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnknownPathException( String aPath, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aPath, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param message the message
	 * @param cause the cause
	 */
	public UnknownPathException( String aPath, String message, Throwable cause ) {
		super( aPath, message, cause );
	}

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param message the message
	 */
	public UnknownPathException( String aPath, String message ) {
		super( aPath, message );
	}

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnknownPathException( String aPath, Throwable aCause, String aErrorCode ) {
		super( aPath, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unknown path exception.
	 *
	 * @param aPath the path
	 * @param cause the cause
	 */
	public UnknownPathException( String aPath, Throwable cause ) {
		super( aPath, cause );
	}
}
